Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(255)

Unified Diff: chrome/browser/memory_details.cc

Issue 164383: Renames the NavigationEntry::display_url() to virtual_url().... (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/automation/automation_provider.cc ('k') | chrome/browser/printing/print_view_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/memory_details.cc
===================================================================
--- chrome/browser/memory_details.cc (revision 23341)
+++ chrome/browser/memory_details.cc (working copy)
@@ -232,7 +232,7 @@
title = L"Untitled";
process.titles.push_back(title);
// We need to check the pending entry as well as the display_url to
// see if it's an about:memory URL (we don't want to count these in the
// total memory usage of the browser).
//
@@ -248,10 +248,10 @@
const NavigationEntry* last_committed_entry =
contents->controller().GetLastCommittedEntry();
if ((last_committed_entry &&
- LowerCaseEqualsASCII(last_committed_entry->display_url().spec(),
+ LowerCaseEqualsASCII(last_committed_entry->virtual_url().spec(),
chrome::kAboutMemoryURL)) ||
(pending_entry &&
- LowerCaseEqualsASCII(pending_entry->display_url().spec(),
+ LowerCaseEqualsASCII(pending_entry->virtual_url().spec(),
chrome::kAboutMemoryURL)))
process.is_diagnostics = true;
}
@@ -232,7 +232,7 @@
title = L"Untitled";
process.titles.push_back(title);
- // We need to check the pending entry as well as the display_url to
+ // We need to check the pending entry as well as the virtual_url to
// see if it's an about:memory URL (we don't want to count these in the
// total memory usage of the browser).
« no previous file with comments | « chrome/browser/automation/automation_provider.cc ('k') | chrome/browser/printing/print_view_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698